@@ -11,19 +11,22 @@ class RequestHandler(base.ValidatingRequestHandler):
 
     NAME = 'authentication-tokens'
 
-    CREATE_SQL = re.sub(r'\s+', ' ', """
+    CREATE_SQL = re.sub(
+        r'\s+', ' ', """
         INSERT INTO v1.authentication_tokens (token, "name", username)
              VALUES (%(token)s, %(name)s, %(username)s)
           RETURNING username, token, "name",
                     created_at, expires_at, last_used_at
         """)
 
-    DELETE_SQL = re.sub(r'\s+', ' ', """
+    DELETE_SQL = re.sub(
+        r'\s+', ' ', """
         DELETE FROM v1.authentication_tokens
               WHERE username = %(username)s
                 AND token = %(token)s""")
 
-    GET_SQL = re.sub(r'\s+', ' ', """
+    GET_SQL = re.sub(
+        r'\s+', ' ', """
         SELECT token, "name", username, created_at, expires_at, last_used_at
           FROM v1.authentication_tokens
          WHERE username = %(username)s
@@ -50,6 +53,6 @@ class RequestHandler(base.ValidatingRequestHandler):
             'token': uuid.UUID(ulid.ULID().hex),
             'username': self.current_user.username
         })
-        result = await self.postgres_execute(
-            self.CREATE_SQL, values, 'create-authentication-token')
+        result = await self.postgres_execute(self.CREATE_SQL, values,
+                                             'create-authentication-token')
         self.send_response(result.row)
