@@ -116,8 +116,10 @@ def load_configuration(config: str, debug: bool) -> typing.Tuple[dict, dict]:
     if automations_sonar.get('url') and automations_sonar.get('admin_token'):
         automations_sonar['enabled'] = True
     footer_link = config.get('footer_link', {})
+    google = config.get('google', {})
     http_settings = config.get('http', {})
     ldap = config.get('ldap', {})
+    local_users = config.get('local_users', {})
     postgres = config.get('postgres', {})
     sentry = config.get('sentry', {})
     session = config.get('session', {})
@@ -181,6 +183,10 @@ def load_configuration(config: str, debug: bool) -> typing.Tuple[dict, dict]:
             'url': footer_link.get('url', '')
         },
         'frontend_url': config.get('frontend_url', None),
+        'google': {
+            'enabled': google.get('enabled', False),
+            'valid_domains': google.get('valid_domains', '').split(',')
+        },
         'javascript_url': config.get('javascript_url', None),
         'ldap': {
             'enabled': ldap.get('enabled'),
@@ -195,6 +201,9 @@ def load_configuration(config: str, debug: bool) -> typing.Tuple[dict, dict]:
             'username': ldap.get('username', 'uid'),
             'users_dn': ldap.get('users_dn')
         },
+        'local_users': {
+            'enabled': local_users.get('enabled', True)
+        },
         'number_of_procs': http_settings.get('processes', 2),
         'opensearch': config.get('opensearch', {}),
         'ops_log_ticket_slug_template': config.get(
