@@ -11,9 +11,8 @@ from itertools import chain
 
 import ldap3
 import psycopg2.errors
-from tornado import web
 
-from imbi import ldap, oauth2, timestamp
+from imbi import errors, ldap, oauth2, timestamp
 
 LOGGER = logging.getLogger(__name__)
 
@@ -22,7 +21,7 @@ class Group:
     """Group class to represent a single group a user is a member of"""
     __slots__ = ['name', 'permissions']
 
-    def __init__(self, name: str, permissions: typing.List[str]):
+    def __init__(self, name: str, permissions: list[str]):
         self.name = name
         self.permissions = sorted(permissions or [])
 
@@ -98,30 +97,24 @@ class User:
              WHERE username = %(username)s
          RETURNING last_seen_at""")
 
-    SQL_UPDATE_USER_FROM_LDAP = re.sub(
+    SQL_UPSERT_USER = re.sub(
         r'\s+', ' ', """\
-        INSERT INTO v1.users (username, user_type, external_id,
-                              display_name, email_address, last_seen_at)
-             VALUES (%(username)s,
-                     %(user_type)s,
-                     %(external_id)s,
-                     %(display_name)s,
-                     %(email_address)s,
-                     CURRENT_TIMESTAMP)
-        ON CONFLICT (username)
-                 DO UPDATE SET email_address = EXCLUDED.email_address,
-                                 external_id = EXCLUDED.external_id,
-                                   user_type = EXCLUDED.user_type,
-                                    password = NULL,
-                                last_seen_at = CURRENT_TIMESTAMP
-                        WHERE users.username = EXCLUDED.username
-          RETURNING last_seen_at""")
+        SELECT v1.upsert_user(%(username)s,
+                              %(user_type)s,
+                              %(external_id)s,
+                              %(display_name)s,
+                              %(email_address)s)
+             AS last_seen_at""")
 
     def __init__(self,
                  application,
                  username: typing.Optional[str] = None,
                  password: typing.Optional[str] = None,
-                 token: typing.Optional[str] = None) -> None:
+                 token: typing.Optional[str] = None,
+                 google_user: bool = False,
+                 display_name: typing.Optional[str] = None,
+                 external_id: typing.Optional[str] = None,
+                 email_address: typing.Optional[str] = None) -> None:
         self._application = application
         self._ldap = ldap.Client(application.settings['ldap'])
         self._ldap_conn: typing.Optional[ldap3.Connection] = None
@@ -129,15 +122,16 @@ class User:
         self.created_at: typing.Optional[datetime.datetime] = None
         self.last_refreshed_at: typing.Optional[datetime.datetime] = None
         self.last_seen_at: typing.Optional[datetime.datetime] = None
-        self.user_type = 'internal'
-        self.external_id: typing.Optional[str] = None
-        self.email_address: typing.Optional[str] = None
-        self.display_name: typing.Optional[str] = None
+        self.user_type = 'google' if google_user else 'internal'
+        self.external_id = external_id
+        self.email_address = email_address
+        self.display_name = display_name
         self._password = password
         self.token = token
-        self.connected_integrations: typing.List[ConnectedIntegration] = []
-        self.groups: typing.List[Group] = []
-        self.permissions: typing.List[str] = []
+        self.integrations: list[str] = []
+        self.groups: list[str] = []
+        self.permissions: list[str] = []
+        self.google_user: bool = google_user
 
     @property
     def password(self):
@@ -162,14 +156,13 @@ class User:
             'last_seen_at': timestamp.isoformat(self.last_seen_at),
             'email_address': self.email_address,
             'display_name': self.display_name,
-            'groups': [g.name for g in self.groups],
+            'groups': self.groups,
             'password': self._application.encrypt_value(
                 '' if self.password is None else self.password),
             'permissions': self.permissions,
             'last_refreshed_at': timestamp.isoformat(self.last_refreshed_at),
-            'integrations': sorted(
-                {app.name
-                 for app in self.connected_integrations}),
+            'integrations': self.integrations,
+            'google_user': self.google_user,
         }
 
     async def authenticate(self) -> bool:
@@ -177,6 +170,8 @@ class User:
         if successful.
 
         """
+        if self.google_user:
+            return True
         if self.token:
             return await self._token_auth()
         result = await self._db_auth()
@@ -195,7 +190,9 @@ class User:
 
     @staticmethod
     def on_postgres_error(_metric_name: str, exc: Exception) -> None:
-        raise web.HTTPError(500, 'System error')
+        LOGGER.error('Database failure: %s: %s', _metric_name, exc)
+        raise errors.DatabaseError(f'Error executing {_metric_name}',
+                                   error=exc)
 
     @classmethod
     def on_token_postgres_error(cls, metric_name: str, exc: Exception) -> None:
@@ -205,12 +202,31 @@ class User:
         return cls.on_postgres_error(metric_name, exc)
 
     async def refresh(self) -> None:
-        """Update the attributes from LDAP"""
-        if self.external_id and self._ldap.is_enabled:
+        """Refresh the user attributes from the respective data store."""
+        if self.google_user:
+            await self._refresh_from_attributes()
+        elif self.external_id and self._ldap.is_enabled:
             await self._ldap_refresh()
         else:
             await self._db_refresh()
 
+    async def _refresh_from_attributes(self):
+        async with self._application.postgres_connector(
+                on_error=self.on_postgres_error) as conn:
+            result = await conn.execute(
+                self.SQL_UPSERT_USER, {
+                    'username': self.username,
+                    'user_type': self.user_type,
+                    'external_id': self.external_id,
+                    'display_name': self.display_name,
+                    'email_address': self.email_address
+                }, 'user-update')
+            self.last_seen_at = result.row['last_seen_at']
+
+        await self._refresh_groups()
+        await self._refresh_integrations()
+        self.last_refreshed_at = max(timestamp.utcnow(), self.last_seen_at)
+
     @property
     def should_refresh(self) -> bool:
         """Returns True if the amount of time that has passed since the last
@@ -235,7 +251,7 @@ class User:
             self.last_seen_at = result.row['last_seen_at']
 
     async def fetch_integration_tokens(self, integration: str) \
-            -> typing.List[oauth2.IntegrationToken]:
+            -> list[oauth2.IntegrationToken]:
         """Retrieve access tokens for the specified integration."""
         obj = await oauth2.OAuth2Integration.by_name(self._application,
                                                      integration)
@@ -264,7 +280,7 @@ class User:
         await self._db_refresh()
         return True
 
-    async def _db_groups(self) -> typing.List[Group]:
+    async def _db_groups(self) -> list[Group]:
         """Return the groups for the user as a list of group objects"""
         async with self._application.postgres_connector(
                 on_error=self.on_postgres_error) as conn:
@@ -282,10 +298,8 @@ class User:
                                         'user-refresh')
         if result:
             self._assign_values(result.row)
-            self.groups = await self._db_groups()
-            self.permissions = sorted(
-                set(chain.from_iterable([g.permissions for g in self.groups])))
-            self.connected_integrations = await self._refresh_integrations()
+            await self._refresh_groups()
+            await self._refresh_integrations()
             self.last_refreshed_at = max(
                 timestamp.utcnow(), self.last_seen_at or timestamp.utcnow())
         else:
@@ -321,7 +335,7 @@ class User:
         async with self._application.postgres_connector(
                 on_error=self.on_postgres_error) as conn:
             result = await conn.execute(
-                self.SQL_UPDATE_USER_FROM_LDAP, {
+                self.SQL_UPSERT_USER, {
                     'username': self.username,
                     'user_type': 'ldap',
                     'external_id': self.external_id,
@@ -339,14 +353,21 @@ class User:
                 'v1.maintain_group_membership_from_ldap_groups',
                 (self.username, ldap_groups), 'user-maintain-groups')
 
-        # Update the groups attribute
-        self.groups = await self._db_groups()
-        self.permissions = sorted(
-            set(chain.from_iterable([g.permissions for g in self.groups])))
-        self.connected_integrations = await self._refresh_integrations()
+        await self._refresh_groups()
+        await self._refresh_integrations()
         self.last_refreshed_at = max(timestamp.utcnow(), self.last_seen_at)
 
-    async def _refresh_integrations(
+    async def _refresh_groups(self):
+        db_groups = await self._db_groups()
+        self.groups = [group.name for group in db_groups]
+        self.permissions = sorted(
+            set(chain.from_iterable([g.permissions for g in db_groups])))
+
+    async def _refresh_integrations(self):
+        self.integrations = sorted(
+            {app.name for app in await self._get_integrations()})
+
+    async def _get_integrations(
             self) -> typing.Sequence[ConnectedIntegration]:
         """Fetch connected integration details from the DB."""
         async with self._application.postgres_connector(
@@ -370,7 +391,7 @@ class User:
         self.groups = []
         self.permissions = []
         self.last_refreshed_at = None
-        self.connected_integrations = []
+        self.integrations = []
 
     async def _token_auth(self) -> bool:
         """Validate via v1.authentication_tokens table"""
